package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.domain.req.PcTDoctorQueryByPageReq;
import com.ruoyi.system.domain.resp.AppDoctorResp;
import com.ruoyi.system.domain.resp.PcTDoctorQueryByPageResp;
import com.ruoyi.system.mapper.TRecordMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TDoctorMapper;
import com.ruoyi.system.domain.TDoctor;
import com.ruoyi.system.service.ITDoctorService;
import org.springframework.util.ObjectUtils;

/**
 * 医生信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-08-03
 */
@Service
public class TDoctorServiceImpl implements ITDoctorService 
{
    @Autowired
    private TDoctorMapper tDoctorMapper;

    @Autowired
    private TRecordMapper tRecordMapper;
    /**
     * 查询医生信息
     * 
     * @param id 医生信息主键
     * @return 医生信息
     */
    @Override
    public TDoctor selectTDoctorById(Long id)
    {
        return tDoctorMapper.selectTDoctorById(id);
    }

    /**
     * 查询医生信息列表
     * 
     * @param tDoctor 医生信息
     * @return 医生信息
     */
    @Override
    public List<TDoctor> selectTDoctorList(TDoctor tDoctor)
    {
        return tDoctorMapper.selectTDoctorList(tDoctor);
    }

    /**
     * 新增医生信息
     * 
     * @param tDoctor 医生信息
     * @return 结果
     */
    @Override
    public int insertTDoctor(TDoctor tDoctor)
    {
        tDoctor.setCreateTime(DateUtils.getNowDate());
        return tDoctorMapper.insertTDoctor(tDoctor);
    }

    /**
     * 修改医生信息
     * 
     * @param tDoctor 医生信息
     * @return 结果
     */
    @Override
    public int updateTDoctor(TDoctor tDoctor)
    {
        tDoctor.setUpdateTime(DateUtils.getNowDate());
        return tDoctorMapper.updateTDoctor(tDoctor);
    }

    /**
     * 批量删除医生信息
     * 
     * @param ids 需要删除的医生信息主键
     * @return 结果
     */
    @Override
    public int deleteTDoctorByIds(Long[] ids)
    {
        return tDoctorMapper.deleteTDoctorByIds(ids);
    }

    /**
     * 删除医生信息信息
     * 
     * @param id 医生信息主键
     * @return 结果
     */
    @Override
    public int deleteTDoctorById(Long id)
    {
        return tDoctorMapper.deleteTDoctorById(id);
    }

    @Override
    public List<PcTDoctorQueryByPageResp> queryByPage(PcTDoctorQueryByPageReq pcTDoctorQueryByPageReq) {
        Long hospitalId = pcTDoctorQueryByPageReq.getHospitalId();
        TRecord record = new TRecord();
        record.setStatus("1");
        record.setHospitalId(hospitalId);
        List<PcTDoctorQueryByPageResp> pcTDoctorQueryByPageResps = tDoctorMapper.queryByPage(pcTDoctorQueryByPageReq);
        pcTDoctorQueryByPageResps.stream().forEach(a ->{
            record.setDoctorId(a.getId());
            List<TRecord> tRecords = tRecordMapper.selectTRecordDoctorFirst(record);
            //最近一次就诊时间
            if (!ObjectUtils.isEmpty(tRecords)){
                a.setLatestTime(tRecords.get(0).getCreateTime());
            }
            //患者个数
            a.setCountPatints(tDoctorMapper.queryPatintCountByDoctor(hospitalId,a.getId()));
            //诊断次数
            a.setCountRecords(tRecords.size());
        });
        return pcTDoctorQueryByPageResps;
    }

    /**
     * 查询医生信息
     *
     * @param id 医生信息主键
     * @return 医生信息
     */
    @Override
    public AppDoctorResp selectAppDoctorDetailById(Long id) {
        return tDoctorMapper.selectAppDoctorDetailById(id);
    }
}
